**Example 1: SwitchGameArchive示例**



Input: 

```
tccli gs SwitchGameArchive --cli-unfold-argument  \
    --GameId 字符串型 \
    --UserId 字符串型 \
    --GameArchiveUrl 字符串型
```

Output: 
```
{
    "Response": {
        "RequestId": "xx"
    }
}
```

